@@ -10,22 +10,7 @@ describe("decorators", function () {
     sourceType: 'module',
     allowImportExportEverywhere: false,
     allowReturnOutsideFunction: false,
-    plugins: [
-      'asyncFunctions',
-      'asyncGenerators',
-      'classConstructorCall',
-      'classProperties',
-      'decorators',
-      'doExpressions',
-      'exponentiationOperator',
-      'exportExtensions',
-      'flow',
-      'functionSent',
-      'functionBind',
-      'jsx',
-      'objectRestSpread',
-      'trailingFunctionCommas'
-    ]
+    plugins: ["*", "jsx", "flow"]
   };
 
   var parseOptions = {
@@ -369,4 +354,13 @@ describe("decorators", function () {
       'fn(test, true);'
     );
   });
+
+  it("should parse and print dynamic import(...)", function () {
+    var code = 'wait(import("oyez"));';
+    var ast = recast.parse(code, parseOptions);
+    assert.strictEqual(
+      recast.prettyPrint(ast).code,
+      code
+    );
+  });
 });
